@@ -2,7 +2,7 @@ package Log::Log4perl::Tiny;
 
 use strict;
 use warnings;
-{ our $VERSION = '1.4.1'; }
+{ our $VERSION = '1.5.0'; }
 
 use Carp;
 use POSIX ();
@@ -366,7 +366,7 @@ sub _carpstuff {
    my $emit_log = shift;
 
    require Carp;
-   local $Carp::Internal{__PACKAGE__()} = 1;
+   local $Carp::Internal{'' . __PACKAGE__} = 1;
 
    my @message;
    @message = __expand_message_list({message => \@_})
